YARP 2.3.5 (2011-06-24)                                                {#v2_3_5}
=======================

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.3.4...v2.3.5`):

```
    17	Paul Fitzpatrick <paulfitz@alum.mit.edu>
     5	Alessandro Scalzo <alessandro.scalzo@iit.it>
     4	Lorenzo Natale <lorenzo.natale@iit.it>
```
